<?php
/**
 * The Sidebar containing the main widget area.
 *
 * @package Catch Themes
 * @subpackage Catch_Box
 * @since Catch Box 1.0
 */
?>

<?php
/**
 * catchbox_before_secondary hook
 */
do_action( 'catchbox_before_secondary' );

$catchbox_layout = catchbox_get_theme_layout();

if ( !is_active_sidebar( 'catchbox_woocommerce_sidebar' ) && ( class_exists( 'Woocommerce' ) && is_woocommerce() ) ) {
	$catchbox_layout = 'no-sidebar';
}

if ( $catchbox_layout == 'left-sidebar' || $catchbox_layout == 'right-sidebar' ) :
	//Getting Ready to load data from Theme Options Panel
	global $post, $wp_query, $catchbox_options_settings;
	$options = $catchbox_options_settings;

	// Front page displays in Reading Settings
	$page_on_front = get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Blog Page setting in Reading Settings
	if ( $page_id == $page_for_posts ) {
		$sidebaroptions = get_post_meta( $page_for_posts, 'catchbox-sidebar-options', true );
	}
	// Post /Page /General Layout
	else if ( $post ) {
 		if ( is_attachment() ) {
			$parent = $post->post_parent;
			$sidebaroptions = get_post_meta( $parent, 'catchbox-sidebar-options', true );
		} else {
			$sidebaroptions = get_post_meta( $post->ID, 'catchbox-sidebar-options', true );
		}
	}
	else {
		$sidebaroptions = '';
	}

	?>
    <aside id="secondary" class="widget-area" role="complementary" aria-label="<?php esc_attr_e( 'Primary Sidebar Widget Area', 'catch-box-pro' ); ?>">
    	<h1 class="screen-reader-text"><?php _e( 'Primary Sidebar Widget Area', 'catch-box-pro' ); ?></h1>
			<?php
		/**
		 * catchbox_before_widget_start hook
		 */
		do_action( 'catchbox_before_widget_start' );

		if ( is_active_sidebar( 'catchbox_woocommerce_sidebar' ) && ( class_exists( 'Woocommerce' ) && is_woocommerce() ) ) {
			dynamic_sidebar( 'catchbox_woocommerce_sidebar' );
		}
		elseif ( is_active_sidebar( 'catchbox_home_sidebar' ) && ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) ) {
            dynamic_sidebar( 'catchbox_home_sidebar' );
        }
		elseif ( ( is_archive() || ( is_home() && $page_for_posts == $page_id ) ) && is_active_sidebar( 'catchbox_archive_sidebar' ) ) {
            dynamic_sidebar( 'catchbox_archive_sidebar' );
        }
		elseif ( is_active_sidebar( 'catchbox_optional_sidebar_one' ) && $sidebaroptions == 'optional-sidebar-one' ) {
			dynamic_sidebar( 'catchbox_optional_sidebar_one' );
		}
		elseif ( is_active_sidebar( 'catchbox_optional_sidebar_two' ) && $sidebaroptions == 'optional-sidebar-two' ) {
			dynamic_sidebar( 'catchbox_optional_sidebar_two' );
		}
		elseif ( is_active_sidebar( 'catchbox_optional_sidebar_three' ) && $sidebaroptions == 'optional-sidebar-three' ) {
			dynamic_sidebar( 'catchbox_optional_sidebar_three' );
		}
		elseif ( is_page_template( 'page-blog.php' ) && is_active_sidebar( 'catchbox_archive_sidebar' ) ) {
        	dynamic_sidebar( 'catchbox_archive_sidebar' );
    	}
        elseif ( is_page() && is_active_sidebar( 'catchbox_page_sidebar' ) ) {
            dynamic_sidebar( 'catchbox_page_sidebar' );
        }
        elseif ( is_single() && is_active_sidebar( 'catchbox_post_sidebar' ) ) {
            dynamic_sidebar( 'catchbox_post_sidebar' );
        }
        elseif ( is_active_sidebar( 'sidebar-1' ) ){
            dynamic_sidebar( 'sidebar-1' );
        }
        else {
        	//Helper Text
			if ( current_user_can( 'edit_theme_options' ) ) { ?>
				<section id="widget-default-text" class="widget widget_text">
		           	<h2 class="widget-title"><?php _e( 'Primary Sidebar Widget Area', 'catch-box-pro' ); ?></h2>
           			<div class="textwidget">
                   		<p><?php _e( 'This is the Primary Sidebar Widget Area if you are using a two column site layout option.', 'catch-box-pro' ); ?></p>
                   		<p><?php printf( __( 'By default it will load Search and Archives widgets as shown below. You can add widget to this area by visiting your <a href="%s">Widgets Panel</a> which will replace default widgets.', 'catch-box-pro' ), admin_url( 'widgets.php' ) ); ?></p>
                 	</div>
	       		</section><!-- #widget-default-text -->
			<?php
			} ?>
        	<section id="archives" class="widget">
				<h2 class="widget-title"><?php _e( 'Archives', 'catch-box-pro' ); ?></h2>
                <div class="widget-content">
                    <ul>
                        <?php wp_get_archives( array( 'type' => 'monthly' ) ); ?>
                    </ul>
                </div>
			</section>
			<section id="default-search" class="widget widget_search">
				<?php get_search_form(); ?>
			</section>
        <?php
    	}

		/**
		 * catchbox_after_widget_start hook
		 */
		do_action( 'catchbox_after_widget_start' );
        ?>
    </aside><!-- #secondary .widget-area -->
<?php endif;
/**
 * catchbox_after_secondary hook
 */
do_action( 'catchbox_after_secondary' );